@@ -19,7 +19,7 @@ use base qw( Exporter );
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 our @aliens;
@@ -124,6 +124,15 @@ sub run_ok
 }
 
 
+sub _flags
+{
+  my($class, $method) = @_;
+  my $static = "${method}_static";
+  $class->can($static)
+    ? $class->$static
+    : $class->$method;
+}
+
 sub xs_ok
 {
   my $cb;
@@ -226,7 +235,7 @@ sub xs_ok
       my $obj = eval {
         $cb->compile(
           source               => $c_filename,
-          extra_compiler_flags => [shellwords map { $_->cflags } @aliens],
+          extra_compiler_flags => [shellwords map { _flags $_, 'cflags' } @aliens],
         );
       };
       ($obj, $@);
@@ -252,7 +261,7 @@ sub xs_ok
           $cb->link(
             objects            => [$obj],
             module_name        => $module,
-            extra_linker_flags => [shellwords map { $_->libs } @aliens],
+            extra_linker_flags => [shellwords map { _flags $_, 'libs' } @aliens],
           );
         };
         ($lib, $@);
@@ -440,7 +449,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -584,11 +593,19 @@ can contain these keys (all of which are optional):
 
 =item cflags
 
-String containing the compiler flags
+String containing the compiler flags.
+
+=item cflags_static
+
+String containing the static compiler flags (optional).
 
 =item libs
 
-String containing the linker and library flags
+String containing the linker and library flags.
+
+=item libs_static
+
+String containing the static linker flags (optional).
 
 =item dynamic_libs
 
