@@ -5,7 +5,7 @@ use warnings;
 use Test2::API qw( context );
 
 # ABSTRACT: A mock alien object for testing
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 sub _def ($) { my($val) = @_; defined $val ? $val : '' }
@@ -14,6 +14,22 @@ sub cflags       { _def shift->{cflags}             }
 sub libs         { _def shift->{libs}               }
 sub dynamic_libs { @{ shift->{dynamic_libs} || [] } }
 
+sub cflags_static
+{
+  my($self) = @_;
+  defined $self->{cflags_static}
+    ? $self->{cflags_static}
+    : $self->cflags;
+}
+
+sub libs_static
+{
+  my($self) = @_;
+  defined $self->{libs_static}
+    ? $self->{libs_static}
+    : $self->libs;
+}
+
 sub bin_dir
 {
   my $dir = shift->{bin_dir};
@@ -34,7 +50,7 @@ Test::Alien::Synthetic - A mock alien object for testing
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -70,10 +86,18 @@ L<Test::Alien#synthetic> function.
 
 String containing the compiler flags
 
+=head2 cflags_static
+
+String containing the static compiler flags
+
 =head2 libs
 
 String containing the linker and library flags
 
+=head2 libs_static
+
+String containing the static linker and library flags
+
 =head2 dynamic_libs
 
 List reference containing the dynamic libraries.
